releases — Transifex v0.9.0 documentation

# Transifex v0.9.0 documentation

# `releases`

## Models

class `Release`(*args, **kwargs)

  A group of packages of actual files, shipped together (eg. Fedora 9).

  Represents a packaging and releasing of a software project (big or small) on a particular date, for which makes sense to track translations across the whole release.

  Examples of Releases is GNOME 2.26, Fedora 10, PackageKit 0.3 etc.